pub fn merge_covered_checkpoint_bound(
covered_checkpoint_bound: Option<u64>,
candidate_bound: u64,
options: &QueryOptions,
) -> Option<u64>Expand description
Merge a fully covered checkpoint candidate into the accumulated inclusive bound. The bound advances by max in ascending scans and min in descending scans.